@@ -1,5 +1,7 @@
 from __future__ import annotations
 
+from typing import Union
+
 import numpy as np
 import pandas as pd
 from sklearn.base import BaseEstimator, TransformerMixin
@@ -7,6 +9,8 @@ from sklearn.base import BaseEstimator, TransformerMixin
 from hcl_model.utils.smooth import smooth_series
 from hcl_model.utils.string_enum import StringEnum
 
+X_TYPE = Union[pd.Series, np.ndarray]
+
 
 class CorrectOutliersMethodNames(StringEnum):
     nothing = "nothing"
@@ -29,14 +33,17 @@ class TargetOutlierCorrectionTransformer(BaseEstimator, TransformerMixin):
         self.ewm_alpha = ewm_alpha
         self.outlier_correction_method = outlier_correction_method
 
-    def fit(self, X: pd.Series, y: pd.Series = None) -> TargetOutlierCorrectionTransformer:
+    def fit(self, X: X_TYPE, y: pd.Series = None) -> TargetOutlierCorrectionTransformer:
         return self
 
-    def transform(self, X: pd.Series) -> pd.Series:
+    def transform(self, X: X_TYPE) -> X_TYPE:
         if self.outlier_correction_method == CorrectOutliersMethodNames.nothing:
             return X
         else:
-            return self._correct_outliers(series=X)
+            if isinstance(X, np.ndarray):
+                return self._correct_outliers(series=pd.Series(X.flatten())).values
+            else:
+                return self._correct_outliers(series=X)
 
     def _correct_outliers(self, series: pd.Series) -> pd.Series:
         is_too_high = self.get_idx_too_high(series=series)
